@@ -133,7 +133,7 @@ pub struct Parallelism {
 }
 
 // Configuration of the `group` subcommand
-#[derive(clap::Args, Debug, Default)]
+#[derive(clap::Args, Clone, Debug, Default)]
 pub struct GroupConfig {
     /// Write the report to a file instead of the standard output
     #[arg(short = 'o', long, value_name = "PATH")]
@@ -729,6 +729,12 @@ pub enum Command {
         #[arg()]
         target: PathBuf,
     },
+
+    /// Print shell completion script to stdout.
+    Complete {
+        /// Shell for which the completion script is generated.
+        shell: clap_complete::Shell,
+    },
 }
 
 impl Command {
@@ -749,8 +755,16 @@ const fn after_help() -> &'static str {
 #[derive(clap::Parser, Debug)]
 #[command(about, author, version, after_help = after_help(), max_term_width = 100)]
 pub struct Config {
-    /// Suppress progress reporting
-    #[arg(short('q'), long)]
+    /// Override progress reporting, by default (=auto) only report when stderr is a terminal.
+    /// Possible values: true, false, auto.
+    #[arg(long, value_name = "VAL", require_equals = true,
+          value_parser(["auto", "true", "false"]), default_value = "auto",
+
+          hide_possible_values = true, hide_default_value = true)]
+    pub progress: String,
+
+    // compatibility with fclones <= 0.34, overrides --progress
+    #[arg(short('q'), long, hide = true)]
     pub quiet: bool,
 
     /// Find files
@@ -801,4 +815,10 @@ mod test {
             config.command,
             Command::Move { target, .. } if target == PathBuf::from("target"));
     }
+
+    #[test]
+    fn test_complete_command() {
+        let config: Config = Config::try_parse_from(vec!["fclones", "complete", "zsh"]).unwrap();
+        assert_matches!(config.command, Command::Complete { shell } if shell == clap_complete::Shell::Zsh);
+    }
 }
