@@ -760,7 +760,7 @@ where
 }
 
 /// Returns the sum of sizes of files in all groups, including duplicates
-fn unique_file_size<'a, T: 'a>(groups: impl IntoIterator<Item = &'a FileGroup<T>>) -> FileLen
+fn unique_file_size<'a, T>(groups: impl IntoIterator<Item = &'a FileGroup<T>>) -> FileLen
 where
     T: AsRef<FileId> + 'a,
 {
@@ -768,7 +768,7 @@ where
 }
 
 /// Sorts each file group by file identifiers
-fn sort_files_by_id<'a, T: 'a>(groups: impl IntoIterator<Item = &'a mut FileGroup<T>>)
+fn sort_files_by_id<'a, T>(groups: impl IntoIterator<Item = &'a mut FileGroup<T>>)
 where
     T: AsRef<FileId> + 'a,
 {
@@ -889,9 +889,7 @@ fn update_file_locations(ctx: &GroupCtx<'_>, groups: &mut (impl FileCollection +
                 // Do not print a notice about slower access when fetching file extents has
                 // failed because a file vanished -- now it will never be accessed anyhow.
                 const ENOENT_NO_SUCH_FILE: i32 = 2;
-                if e.raw_os_error()
-                    .map_or(true, |err| err != ENOENT_NO_SUCH_FILE)
-                {
+                if e.raw_os_error() != Some(ENOENT_NO_SUCH_FILE) {
                     handle_fetch_physical_location_err(ctx, &err_counters, fi, e)
                 }
             }
@@ -2087,6 +2085,7 @@ mod test {
         let mut file = OpenOptions::new()
             .write(true)
             .create(true)
+            .truncate(true)
             .open(path)
             .unwrap();
         file.write_all(prefix).unwrap();
