@@ -134,7 +134,11 @@ fn reflink_overwrite(target: &std::path::Path, link: &std::path::Path) -> io::Re
     let src = fs::File::open(target)?;
 
     // This operation does not require `.truncate(true)` because the files are already of the same size.
-    let dest = fs::OpenOptions::new().create(true).write(true).open(link)?;
+    let dest = fs::OpenOptions::new()
+        .create(true)
+        .truncate(false)
+        .write(true)
+        .open(link)?;
 
     // From /usr/include/linux/fs.h:
     // #define FICLONE		_IOW(0x94, 9, int)
@@ -354,7 +358,7 @@ pub mod test {
             pub static ref SEQUENTIAL_REFLINK_TESTS: Mutex<()> = Mutex::default();
         }
 
-        pub struct CrossTest<'a>(MutexGuard<'a, ()>);
+        pub struct CrossTest<'a>(#[allow(dead_code)] MutexGuard<'a, ()>);
         impl<'a> CrossTest<'a> {
             pub fn new(crosstest: bool) -> CrossTest<'a> {
                 let x = CrossTest(SEQUENTIAL_REFLINK_TESTS.lock().unwrap());
@@ -363,7 +367,7 @@ pub mod test {
             }
         }
 
-        impl<'a> Drop for CrossTest<'a> {
+        impl Drop for CrossTest<'_> {
             fn drop(&mut self) {
                 *CROSSTEST.lock().unwrap() = false;
             }
@@ -398,7 +402,7 @@ pub mod test {
         with_dir(test_root, |root| {
             // Always clean up files in /dev/shm, even after failure
             struct CleanupGuard<'a>(&'a str);
-            impl<'a> Drop for CleanupGuard<'a> {
+            impl Drop for CleanupGuard<'_> {
                 fn drop(&mut self) {
                     fs::remove_dir_all(self.0).unwrap();
                 }
