@@ -10,21 +10,21 @@ cd "$(dirname $0)/.."
 
 echo "${bold}Building${normal}"
 set -x
-cargo build --release
-cargo build --release --target i686-unknown-linux-musl
+cargo build --release --target x86_64-unknown-linux-gnu
 cargo build --release --target x86_64-unknown-linux-musl
+cargo build --release --target i686-unknown-linux-musl
 cargo build --release --target x86_64-pc-windows-gnu
 set +x
 
-echo "${bold}Packaging${normal}"
+echo "${bold}Packaging${normal} fclones"
 set -x
-VERSION=$(cargo pkgid | sed 's/.*#//')
-PKG_DIR=target/packages/$VERSION
+VERSION=$(cargo pkgid -p fclones | sed 's/.*#//')
+PKG_DIR=target/packages/fclones-$VERSION
 mkdir -p $PKG_DIR
 rm -f $PKG_DIR/*
 
-cargo deb
-mv target/debian/*.deb $PKG_DIR
+cargo deb -p fclones --target x86_64-unknown-linux-gnu
+mv target/x86_64-unknown-linux-gnu/debian/*.deb $PKG_DIR
 
 fakeroot alien --to-rpm -c $PKG_DIR/*.deb
 mv *.rpm $PKG_DIR
